# Changelog

## [1.2.3](https://github.com/spotify/confidence-sdk-python/compare/v1.2.2...v1.2.3) (2025-04-28)


### 🐛 Bug Fixes

* change how we log resolve tester hints ([#89](https://github.com/spotify/confidence-sdk-python/issues/89)) ([077ddf6](https://github.com/spotify/confidence-sdk-python/commit/077ddf68df9b2cf64fc03efaa8a6ba94c3302fc5))

## [1.2.2](https://github.com/spotify/confidence-sdk-python/compare/v1.2.1...v1.2.2) (2025-04-22)


### 🧹 Chore

* remove container spec in release job ([#86](https://github.com/spotify/confidence-sdk-python/issues/86)) ([78a5611](https://github.com/spotify/confidence-sdk-python/commit/78a561172aa3c82afb2759c31244fb8b5f6225df))

## [1.2.1](https://github.com/spotify/confidence-sdk-python/compare/v1.2.0...v1.2.1) (2025-04-22)


### 🐛 Bug Fixes

* release using trusted publishing ([#84](https://github.com/spotify/confidence-sdk-python/issues/84)) ([a8c6953](https://github.com/spotify/confidence-sdk-python/commit/a8c6953b824960ac11cb8ecca2745e7391344ec5))

## [1.2.0](https://github.com/spotify/confidence-sdk-python/compare/v1.1.0...v1.2.0) (2025-04-17)


### ✨ New Features

* add support for setting resolve timeout ([#82](https://github.com/spotify/confidence-sdk-python/issues/82)) ([469be0d](https://github.com/spotify/confidence-sdk-python/commit/469be0dfcee28c3bbbd8cda28ea2c7bfc7f68b35))

## [1.1.0](https://github.com/spotify/confidence-sdk-python/compare/v1.0.1...v1.1.0) (2024-12-12)


### 🐛 Bug Fixes

* Resolve debug URL uses flag id ([#79](https://github.com/spotify/confidence-sdk-python/issues/79)) ([ad40666](https://github.com/spotify/confidence-sdk-python/commit/ad4066695c3e0819db56b2b9de9c5be705c194fe))
* Resolve handling uses flag id ([ad40666](https://github.com/spotify/confidence-sdk-python/commit/ad4066695c3e0819db56b2b9de9c5be705c194fe))


### ✨ New Features

* add resolve debugger logging ([#77](https://github.com/spotify/confidence-sdk-python/issues/77)) ([1b34daf](https://github.com/spotify/confidence-sdk-python/commit/1b34daf4f2742474be09564611a267d73819bee4))

## [1.0.1](https://github.com/spotify/confidence-sdk-python/compare/v1.0.0...v1.0.1) (2024-11-07)


### 🧹 Chore

* declare httpx in pyproject.toml ([#69](https://github.com/spotify/confidence-sdk-python/issues/69)) ([ed51321](https://github.com/spotify/confidence-sdk-python/commit/ed513214cdeef61cc8b01d5cd80860d44e206a56))


### 📚 Documentation

* minor readme formatting fix ([#68](https://github.com/spotify/confidence-sdk-python/issues/68)) ([7362a6f](https://github.com/spotify/confidence-sdk-python/commit/7362a6f92559082f4a00c92693468b3881af84f6))

## [1.0.0](https://github.com/spotify/confidence-sdk-python/compare/v0.2.6...v1.0.0) (2024-11-05)


### ✨ New Features

* add support for async methods  ([#65](https://github.com/spotify/confidence-sdk-python/issues/65)) ([a06a18b](https://github.com/spotify/confidence-sdk-python/commit/a06a18bbe1a9686de07571c4b07eddd8c1a61117))


### 🔄 Refactoring

* code reuse and test split ([#67](https://github.com/spotify/confidence-sdk-python/issues/67)) ([5dd55cc](https://github.com/spotify/confidence-sdk-python/commit/5dd55cc7b9f26d1efb5e4efc3750aff4410f149a))

## [0.2.6](https://github.com/spotify/confidence-sdk-python/compare/v0.2.5...v0.2.6) (2024-09-11)


### ✨ New Features

* Update base url ([#63](https://github.com/spotify/confidence-sdk-python/issues/63)) ([cc97e9e](https://github.com/spotify/confidence-sdk-python/commit/cc97e9e6162ed945198901a448c64421c66c8f89))

## [0.2.5](https://github.com/spotify/confidence-sdk-python/compare/v0.2.4...v0.2.5) (2024-09-09)


### ✨ New Features

* Sidecar - Let users to add custom resolve url for confidence object ([#62](https://github.com/spotify/confidence-sdk-python/issues/62)) ([f6244dd](https://github.com/spotify/confidence-sdk-python/commit/f6244ddf37b13ee4e6f0e728d9a85505c800f257))


### 📚 Documentation

* Update the README ([#60](https://github.com/spotify/confidence-sdk-python/issues/60)) ([aaa4bbc](https://github.com/spotify/confidence-sdk-python/commit/aaa4bbceebf60e415098651973b22c42e8cbbb97))

## [0.2.4](https://github.com/spotify/confidence-sdk-python/compare/v0.2.3...v0.2.4) (2024-07-09)


### 🐛 Bug Fixes

* Do not raise exception for track events ([#58](https://github.com/spotify/confidence-sdk-python/issues/58)) ([627d970](https://github.com/spotify/confidence-sdk-python/commit/627d9705973ea39cbe3321341659be3228dbf814))

## [0.2.3](https://github.com/spotify/confidence-sdk-python/compare/v0.2.2...v0.2.3) (2024-06-03)


### 🐛 Bug Fixes

* revert having run in the track event ([#56](https://github.com/spotify/confidence-sdk-python/issues/56)) ([f87032a](https://github.com/spotify/confidence-sdk-python/commit/f87032a9b7f5d927f0e38fdb78d38fb52acc4bb2))

## [0.2.2](https://github.com/spotify/confidence-sdk-python/compare/v0.2.1...v0.2.2) (2024-06-03)


### 🐛 Bug Fixes

* Add readme for confidence flag api ([#53](https://github.com/spotify/confidence-sdk-python/issues/53)) ([f840603](https://github.com/spotify/confidence-sdk-python/commit/f840603616953b1b3d551b950aa2a689023d99bf))
* run async io task in the background ([#55](https://github.com/spotify/confidence-sdk-python/issues/55)) ([e7c87bd](https://github.com/spotify/confidence-sdk-python/commit/e7c87bdfb72e5f1b62ae5cbcf1d813eb965b7797))

## [0.2.1](https://github.com/spotify/confidence-sdk-python/compare/v0.2.0...v0.2.1) (2024-05-29)


### 🐛 Bug Fixes

* Change the artifact name for the library to confidence-sdk ([#51](https://github.com/spotify/confidence-sdk-python/issues/51)) ([6ad000f](https://github.com/spotify/confidence-sdk-python/commit/6ad000f22f793f8b263f710bf6918ea71adfeaa3))

## [0.2.0](https://github.com/spotify/confidence-sdk-python/compare/v0.1.4...v0.2.0) (2024-05-29)


### ⚠ BREAKING CHANGES

* total confidence ([#49](https://github.com/spotify/confidence-sdk-python/issues/49))

### ✨ New Features

* total confidence ([#49](https://github.com/spotify/confidence-sdk-python/issues/49)) ([58437a3](https://github.com/spotify/confidence-sdk-python/commit/58437a355b4cad235b61b9a61c7b0131ad926c55))

## [0.1.4](https://github.com/spotify/confidence-sdk-python/compare/v0.1.3...v0.1.4) (2024-02-13)


### 🐛 Bug Fixes

* add a default endpoint to the provider ([#46](https://github.com/spotify/confidence-sdk-python/issues/46)) ([1f30ef7](https://github.com/spotify/confidence-sdk-python/commit/1f30ef7583939967407f11fbeb797c07bb06d9f3))
* fixes to enable mypy in premerge ([#42](https://github.com/spotify/confidence-sdk-python/issues/42)) ([c1d65bf](https://github.com/spotify/confidence-sdk-python/commit/c1d65bf3a7338cee920ce3936e2bcbc6a98e4095))


### 🧹 Chore
* update OF sdk to 0.4.2 ([dd4a4d7](https://github.com/spotify/confidence-sdk-python/commit/dd4a4d74cb91331ce6768ef12ee08b14b89c7eac)

* explicitly add the typing-extensions dep ([49ac4eb](https://github.com/spotify/confidence-sdk-python/commit/49ac4ebbb23fa28f1f6d69b6fea29e000ef63759))

* update openfeature sdk version to 0.4.1 ([#35](https://github.com/spotify/confidence-sdk-python/issues/35)) ([16ee55f](https://github.com/spotify/confidence-sdk-python/commit/16ee55f804b3a488926647a697cf37a4bf25af69))


### 📚 Documentation

* Add Confidence link to the README ([#44](https://github.com/spotify/confidence-sdk-python/issues/44)) ([bee1d17](https://github.com/spotify/confidence-sdk-python/commit/bee1d175a0478abc18a196d3bd2f48ffe8ab0005))

## [0.1.3](https://github.com/spotify/confidence-sdk-python/compare/v0.1.2...v0.1.3) (2023-11-16)


### 🐛 Bug Fixes

* check types with mypy ([#31](https://github.com/spotify/confidence-sdk-python/issues/31)) ([e6d4dcd](https://github.com/spotify/confidence-sdk-python/commit/e6d4dcd664971935905dc58d0681ecc46b0063de))


### ✨ New Features

* Add SDK id and version to requests ([#34](https://github.com/spotify/confidence-sdk-python/issues/34)) ([6c82014](https://github.com/spotify/confidence-sdk-python/commit/6c82014717feaa4a13db9397cbdf7ff71e504c17))

## [0.1.2](https://github.com/spotify/confidence-sdk-python/compare/v0.1.1...v0.1.2) (2023-10-09)


### 🐛 Bug Fixes

* update to openfeature 0.3.1 and fix some type issues ([#29](https://github.com/spotify/confidence-sdk-python/issues/29)) ([6c0c5b1](https://github.com/spotify/confidence-sdk-python/commit/6c0c5b11194d614aea93e661ad28c11c2b54b627))

## [0.1.1](https://github.com/spotify/confidence-sdk-python/compare/v0.1.0...v0.1.1) (2023-09-18)


### 🐛 Bug Fixes

* make _select a static method ([#22](https://github.com/spotify/confidence-sdk-python/issues/22)) ([0ad2b88](https://github.com/spotify/confidence-sdk-python/commit/0ad2b8863adaf9b8ade87d7504d461737763693f))


### 📚 Documentation

* update CONTRIBUTING.md ([#26](https://github.com/spotify/confidence-sdk-python/issues/26)) ([b574341](https://github.com/spotify/confidence-sdk-python/commit/b57434152e914768e16191195f36f059fb3a929a))

## 0.1.0 (2023-09-14)


### 🐛 Bug Fixes

* allow omitting targeting key ([#17](https://github.com/spotify/confidence-sdk-python/issues/17)) ([ddb535f](https://github.com/spotify/confidence-sdk-python/commit/ddb535fb197fa958d42d33a540de6a8c3b5c5f00))
* int syntax error in resolver ([#14](https://github.com/spotify/confidence-sdk-python/issues/14)) ([5e4dcdd](https://github.com/spotify/confidence-sdk-python/commit/5e4dcddee5a4a053a266fff6f1ce46a445907a86))
* make resolve payload have appended "flags/" ([#18](https://github.com/spotify/confidence-sdk-python/issues/18)) ([97c6f9a](https://github.com/spotify/confidence-sdk-python/commit/97c6f9a0faf7c5d894fc540e0d415cd2cf248f7a))


### ✨ New Features

* make apply on resolve configurable. ([#7](https://github.com/spotify/confidence-sdk-python/issues/7)) ([50a06a8](https://github.com/spotify/confidence-sdk-python/commit/50a06a89e30443a5c994581081b9e0a82e86ec18)), closes [#2](https://github.com/spotify/confidence-sdk-python/issues/2)


### 🧹 Chore

* test to start from 0 ([f67395f](https://github.com/spotify/confidence-sdk-python/commit/f67395f7005642da78a8107e702ad32c5976bdca))


### 📦 Dependencies

* bump to openfeature sdk v0.2.0 ([#12](https://github.com/spotify/confidence-sdk-python/issues/12)) ([2f8b8a6](https://github.com/spotify/confidence-sdk-python/commit/2f8b8a600abe0719fb2aa6fc9389b6f2257ee07f))


### 🔄 Refactoring

* module restructure ([#15](https://github.com/spotify/confidence-sdk-python/issues/15)) ([341577a](https://github.com/spotify/confidence-sdk-python/commit/341577ab450a8f182de3802ba62a2a2f0551601d))
